#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2022-10-04
# File  : wato/active_checks_radius.py
#
# 2024-01-01: modified for cmk 2.2.x

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    TextAscii,
    Transform,
)

from cmk.gui.plugins.wato.active_checks.common import RulespecGroupActiveChecks
from cmk.gui.plugins.wato.utils import HostRulespec, rulespec_registry, IndividualOrStoredPassword


def _valuespec_active_checks_radius():
    return Transform(
        Dictionary(
            title=_('Check RADIUS service'),
            help=_(''),
            elements=[
                ('description',
                 TextAscii(
                     title=_('Service description'),
                     help=_(
                         'Must be unique for every host. The service description starts always with \"RADIUS server\".'),
                     size=50,
                     placeholder='Item name for the service',
                     allow_empty=False,
                 )),
                ('server',
                 TextAscii(
                     title=_('Server IP-address or name'),
                     help=_(
                         'Hostname or IP-address to monitor. Default is the host name/IP-Address of the monitored host.'
                     ),
                     size=50,
                     allow_empty=False,
                 )),
                ('auth_port',
                 Integer(
                     title=_('RADIUS authentication port'),
                     help=_('The RADIUS port to use for authentication. Default is 1812.'),
                     # size=5,
                     default_value=1812,
                     minvalue=1,
                     maxvalue=65535,
                 )),
                ('secret',
                 IndividualOrStoredPassword(
                     title=_('Server secret'),
                     help=_('The RADIUS secret.'),
                     # size=50,
                     allow_empty=False,
                 )),
                ('timeout',
                 Integer(
                     title=_('Server timeout'),
                     help=_('The user password.'),
                     default_value=2,
                     minvalue=1,
                     maxvalue=30,
                 )),
                ('user_name',
                 TextAscii(
                     title=_('User name'),
                     help=_('The user name to use in the request.'),
                     size=50,
                     placeholder='user name to use in the request',
                     allow_empty=False,
                 )),
                ('user_password',
                 IndividualOrStoredPassword(
                     title=_('User password'),
                     help=_('The user password.'),
                     # size=50,
                     allow_empty=False
                 )),
            ],
            required_keys=['secret']
        ),
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupActiveChecks,
        match_type='all',
        name='active_checks:radius',
        valuespec=_valuespec_active_checks_radius,
    )
)
